@@ -268,11 +268,10 @@ OC.L10N.register(
     "Add Talk conversation" : "Додати розмову Talk",
     "Fetching Talk rooms…" : "Отримання кімнат Talk...",
     "No Talk room available" : "Відсутні кімнати Talk",
-    "Create a new conversation" : "Створити нову розмову",
+    "Create a new public conversation" : "Створити нову публічну розмову",
     "Select conversation" : "Вибрати розмову",
     "on" : "о",
     "at" : "о",
-    "Reminder" : "Нагадування",
     "before at" : "до о",
     "Notification" : "Сповіщення",
     "Email" : "Ел.пошта",
@@ -283,7 +282,6 @@ OC.L10N.register(
     "Edit time" : "Редагувати час",
     "Save time" : "Зберегти час",
     "Remove reminder" : "Прибрати нагадування",
-    "+ Add reminder" : "+ Додати нагадування",
     "Add reminder" : "Додати нагадування",
     "seconds" : "секунд",
     "minutes" : "хвилин",
@@ -319,26 +317,28 @@ OC.L10N.register(
     "Awaiting response" : "Очікується відповідь",
     "Checking availability" : "Перевірка доступності",
     "Has not responded to {organizerName}'s invitation yet" : "Ще не відповів на запрошення від {organizerName}",
-    "Select automatic slot" : "Виберіть автоматичний проміжок",
+    "Suggested times" : "Пропонований час",
     "chairperson" : "модератор",
     "required participant" : "обов'язковий учасник(-ця)",
     "non-participant" : "гість",
     "optional participant" : "необов'язковий учасник(-ця)",
     "{organizer} (organizer)" : "{organizer} (організатор)",
     "{attendee} ({role})" : "{attendee} ({role})",
-    "Free" : "Вільно",
-    "Busy (tentative)" : "Зайнято (попередньо)",
-    "Busy" : "Зайнято",
-    "Out of office" : "Недоступно",
-    "Unknown" : "Невідомо",
     "Availability of attendees, resources and rooms" : "Доступність учасників, ресурсів і приміщень",
-    "with" : "із",
-    "Available times:" : "Доступні проміжки:",
     "Suggestion accepted" : "Пропозицію прийнято",
+    "Previous date" : "Попередня дата",
+    "Next date" : "Наступна дата",
+    "Legend" : "Легенда",
+    "Out of office" : "Недоступно",
+    "Attendees:" : "Учасники:",
     "Done" : "Готово",
     "Search room" : "Шукати кімнату",
     "Room name" : "Назва кімнати",
     "Check room availability" : "Перевірити доступність кімнати",
+    "Free" : "Вільно",
+    "Busy (tentative)" : "Зайнято (попередньо)",
+    "Busy" : "Зайнято",
+    "Unknown" : "Невідомо",
     "Find a time" : "Знайти час",
     "The invitation has been accepted successfully." : "Запрошення успішно прийнято.",
     "Failed to accept the invitation." : "Не вдалося прийняти запрошення.",
@@ -378,8 +378,8 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Не вдалося змінити цілодобове налаштування для подій, які є повторювальними подіями.",
     "From" : "Від",
     "To" : "Кому",
-    "All day" : "Весь день",
     "Repeat" : "Повторювати",
+    "Repeat event" : "Повторювати подію",
     "_time_::_times_" : ["раз","разів","разів","разів"],
     "never" : "завжди",
     "on date" : "дата",
@@ -402,7 +402,7 @@ OC.L10N.register(
     "Does not repeat" : "Не повторюється",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Правила повторювання ціє події не повністю підтримуються у Nextcloud. Після зміни налаштувань деякі повторення можуть зникнути.",
     "No rooms or resources yet" : "Поки відсутні кімнати та ресурси",
-    "Suggestions" : "Пропозиції",
+    "Resources" : "Ресурси",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} місце","{seatingCapacity} місця","{seatingCapacity} місць","{seatingCapacity} місць"],
     "Add resource" : "Додати ресурс",
     "Has a projector" : "Має проєктор",
@@ -446,7 +446,6 @@ OC.L10N.register(
     "No valid public calendars configured" : "Не налаштовано жодного дійсного публічного календаря",
     "Speak to the server administrator to resolve this issue." : "Зверніться до адміністратора сервера, щоб вирішити цю проблему.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Календарі публічних свят надаються Thunderbird. Календарні дані буде отримано з {website}",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Ці публічні календарі були запропоновані адміністратором сервера. Дані для календаря будуть отримані з відповідного сайту.",
     "By {authors}" : "Автор: {authors}",
     "Subscribed" : "Підписано",
     "Subscribe" : "Підписатися",
@@ -469,16 +468,16 @@ OC.L10N.register(
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Вашу часову зону автоматично встановлено як UTC.\nСкоріш за все це зумовлено безпековими обмеженнями вашого бравзера.\nБудь ласка, налаштуйте вашу часову зону  вручну у налаштуваннях календаря.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Не знайдено налаштування вашої часової зони ({timezoneId}). Не вдалося встановити типову часову зону UTC.\nБудь ласка, змініть вашу часову зону у налаштуваннях та надішліть звіт про помилку.",
     "Availability of {displayName}" : "Доступність {displayName}",
+    "Edit event" : "Редагувати подію",
     "Event does not exist" : "Подія відсутня",
     "Duplicate" : "Копіювати",
     "Delete this occurrence" : "Вилучити повторення",
     "Delete this and all future" : "Вилучити це та всі подальші повторення",
+    "All day" : "Весь день",
     "Modifications wont get propagated to the organizer and other attendees" : "Зміни не буде надіслано організаторові та іншим учасникам",
-    "Details" : "Деталі",
     "Managing shared access" : "Керування спільним доступом",
     "Deny access" : "Заборонити доступ",
     "Invite" : "Запросити",
-    "Resources" : "Ресурси",
     "_User requires access to your file_::_Users require access to your file_" : ["Потрібно надати доступ до вашого файлу.","Потрібно надати доступ до вашого файлу.","Потрібно надати доступ до вашого файлу.","Потрібно надати доступ до вашого файлу."],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Для доступу до застосунку потрібний спільний доступ.","Для доступу до застосунків потрібний спільний доступ.","Для доступу до застосунків потрібний спільний доступ.","Для доступу до застосунків потрібний спільний доступ."],
     "Untitled event" : "Подія без назви",
@@ -576,7 +575,10 @@ OC.L10N.register(
     "Special color of this event. Overrides the calendar-color." : "Власний колір для цієї події. Перезаписати колір календаря.",
     "Error while sharing file" : "Помилка під час надання спільного доступу до файлу",
     "Error while sharing file with user" : "Помилка під час надання доступу користувачеві",
+    "Error creating a folder {folder}" : "Помилка під час надання створення каталогу {folder}",
     "Attachment {fileName} already exists!" : "Долучений файл {filename} вже присутній!",
+    "Attachment {fileName} added!" : "Вкладення {fileName} додано! ",
+    "An error occurred during uploading file {fileName}" : "Помилка під час завантаження файлу {fileName}",
     "An error occurred during getting file information" : "Помилка під час отримання інформації про файл",
     "Talk conversation for event" : "Розмова Talk для події",
     "An error occurred, unable to delete the calendar." : "Помилка: неможливо вилучити календар.",
@@ -584,6 +586,14 @@ OC.L10N.register(
     "This is an event reminder." : "Це нагадування про подію.",
     "Error while parsing a PROPFIND error" : "Помилка під час обробки помилки PROPFIND",
     "Appointment not found" : "Запрошення на зустріч не знайдено",
-    "User not found" : "Користувача не знайдено"
+    "User not found" : "Користувача не знайдено",
+    "Create a new conversation" : "Створити нову розмову",
+    "Reminder" : "Нагадування",
+    "+ Add reminder" : "+ Додати нагадування",
+    "Select automatic slot" : "Виберіть автоматичний проміжок",
+    "with" : "із",
+    "Available times:" : "Доступні проміжки:",
+    "Suggestions" : "Пропозиції",
+    "Details" : "Деталі"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
